==> jc-1.4.0.tar.gz: java/net/ProtocolException.h <==
// public class java.net.ProtocolException

// class file dependencies
// @dep_class 4e0a56550c69d57c java_io_IOException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 30557cd062cca437 java_net_ProtocolException

// header file dependencies
// @dep_header java_io_IOException

#include "java/io/IOException.h"

#ifndef _JC_java_net_ProtocolException_H_
#define _JC_java_net_ProtocolException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_net_ProtocolException$sub_refs	_jc_java_net_ProtocolException$sub_refs;
typedef struct _jc_java_net_ProtocolException$sub_nonrefs	_jc_java_net_ProtocolException$sub_nonrefs;
typedef struct _jc_java_net_ProtocolException$refs	_jc_java_net_ProtocolException$refs;
typedef struct _jc_java_net_ProtocolException$nonrefs	_jc_java_net_ProtocolException$nonrefs;
typedef struct _jc_java_net_ProtocolException$object	_jc_java_net_ProtocolException$object;

typedef struct _jc_java_net_ProtocolException$fields_struct	_jc_java_net_ProtocolException$fields_struct;
typedef const struct _jc_java_net_ProtocolException$vmethods	_jc_java_net_ProtocolException$vmethods;
typedef const struct _jc_java_net_ProtocolException$vtable	_jc_java_net_ProtocolException$vtable;
typedef const struct _jc_java_net_ProtocolException$vtype	_jc_java_net_ProtocolException$vtype;

// Class fields structure
struct _jc_java_net_ProtocolException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_net_ProtocolException$fields_struct _jc_java_net_ProtocolException$class_fields;

// Constructors
extern void _jc_java_net_ProtocolException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_net_ProtocolException$object *);
extern void _jc_java_net_ProtocolException$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_net_ProtocolException$object *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_java_net_ProtocolException$vmethods {
};

// Vtable
struct _jc_java_net_ProtocolException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_io_IOException$vmethods	java_io_IOException;
	_jc_java_net_ProtocolException$vmethods	java_net_ProtocolException;
};

// Vtype
struct _jc_java_net_ProtocolException$vtype {
	_jc_type			type;
	_jc_java_net_ProtocolException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_net_ProtocolException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_net_ProtocolException$refs {
    _jc_java_net_ProtocolException$sub_refs	java_net_ProtocolException;
    _jc_java_io_IOException$sub_refs	java_io_IOException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_net_ProtocolException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_net_ProtocolException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_io_IOException$sub_nonrefs	java_io_IOException;
    _jc_java_net_ProtocolException$sub_nonrefs	java_net_ProtocolException;
};

// Object instance structure
struct _jc_java_net_ProtocolException$object {
	_jc_java_net_ProtocolException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_net_ProtocolException$vtype	*vtype;
	_jc_java_net_ProtocolException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_net_ProtocolException$vtype _jc_java_net_ProtocolException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_net_ProtocolException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_net_ProtocolException$class_object;

#endif	/* _JC_java_net_ProtocolException_H_ */

==> jc-1.4.6.tar.gz: java/net/ProtocolException.h <==
// public class java.net.ProtocolException

// class file dependencies
// @dep_class 4e0a56550c69d57c java_io_IOException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 30557cd062cca437 java_net_ProtocolException

// header file dependencies
// @dep_header java_io_IOException

#include "java/io/IOException.h"

#ifndef _JC_java_net_ProtocolException_H_
#define _JC_java_net_ProtocolException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_net_ProtocolException$sub_refs	_jc_java_net_ProtocolException$sub_refs;
typedef struct _jc_java_net_ProtocolException$sub_nonrefs	_jc_java_net_ProtocolException$sub_nonrefs;
typedef struct _jc_java_net_ProtocolException$refs	_jc_java_net_ProtocolException$refs;
typedef struct _jc_java_net_ProtocolException$nonrefs	_jc_java_net_ProtocolException$nonrefs;
typedef struct _jc_java_net_ProtocolException$object	_jc_java_net_ProtocolException$object;

typedef struct _jc_java_net_ProtocolException$fields_struct	_jc_java_net_ProtocolException$fields_struct;
typedef const struct _jc_java_net_ProtocolException$vmethods	_jc_java_net_ProtocolException$vmethods;
typedef const struct _jc_java_net_ProtocolException$vtable	_jc_java_net_ProtocolException$vtable;
typedef const struct _jc_java_net_ProtocolException$vtype	_jc_java_net_ProtocolException$vtype;

// Class fields structure
struct _jc_java_net_ProtocolException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_net_ProtocolException$fields_struct _jc_java_net_ProtocolException$class_fields;

// Constructors
extern void _jc_java_net_ProtocolException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_net_ProtocolException$object *) _JC_JCNI_ATTR;
extern void _jc_java_net_ProtocolException$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_net_ProtocolException$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_net_ProtocolException$vmethods {
};

// Vtable
struct _jc_java_net_ProtocolException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_io_IOException$vmethods	java_io_IOException;
	_jc_java_net_ProtocolException$vmethods	java_net_ProtocolException;
};

// Vtype
struct _jc_java_net_ProtocolException$vtype {
	_jc_type			type;
	_jc_java_net_ProtocolException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_net_ProtocolException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_net_ProtocolException$refs {
    _jc_java_net_ProtocolException$sub_refs	java_net_ProtocolException;
    _jc_java_io_IOException$sub_refs	java_io_IOException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_net_ProtocolException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_net_ProtocolException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_io_IOException$sub_nonrefs	java_io_IOException;
    _jc_java_net_ProtocolException$sub_nonrefs	java_net_ProtocolException;
};

// Object instance structure
struct _jc_java_net_ProtocolException$object {
	_jc_java_net_ProtocolException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_net_ProtocolException$vtype	*vtype;
	_jc_java_net_ProtocolException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_net_ProtocolException$vtype _jc_java_net_ProtocolException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_net_ProtocolException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_net_ProtocolException$class_object;

#endif	/* _JC_java_net_ProtocolException_H_ */
